<?php
/**
 * @file
 * A quick interface to the Formstack API. Documentation to the API can be
 * found here: http://support.formstack.com/index.php?pg=kb.book&id=3
 * @author michael
 */

class Formstack {

  public static $apiUrl = 'https://www.formstack.com/api';

  /**
   * Makes a Formstack API request.
   *
   * This function uses v1 of the Formstack API
   * and returns a JSON decoded response.
   *
   * @param string $api_key
   *   The Formstack API key
   * @param string $method
   *   The API web method
   * @param array $args
   *   The parameters for the API request
   *
   * @return stdobject
   *   The JSON decodes response
   */
  public static function request($api_key, $method, $args = array()) {

    $args['api_key'] = $api_key;
    $args['type'] = 'json';

    $url = self::$apiUrl . "/" . $method;

    $res = @file_get_contents("{$url}?" . http_build_query($args, '', '&'));

    if ($res === FALSE) {
      return FALSE;
    }

    return json_decode($res);
  }

  /**
   * Returns a list of forms.
   *
   * @param string $api_key
   *   The Formstack API key
   *
   * @return array
   *   An array of forms.
   */
  public static function forms($api_key) {

    if (!empty($api_key)) {

      $res = Formstack::request($api_key, 'forms');

      if ($res === FALSE) {
        return FALSE;
      }

      if ($res->status == 'ok') {
        return $res->response->forms;
      }
    }
    else {
      return array();
    }
  }
}
